==> ono_1.8.8.jar: edu/northwestern/ono/ui/items/CosineSimilarityItem.java <==
/**
 * Ono Project
 *
 * File:         CustomerItem.java
 * RCS:          $Id: CosineSimilarityItem.java,v 1.6 2008/01/01 00:12:51 drc915 Exp $
 * Description:  CustomerItem class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 24, 2007 at 3:34:16 PM
 * Language:     Java
 * Package:      edu.northwestern.ono.ui.items
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.ono.ui.items;

import java.util.List;

import org.gudy.azureus2.plugins.ui.tables.TableCell;
import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;

import edu.northwestern.ono.MainGeneric;
import edu.northwestern.ono.tables.utils.CoreTableColumn;

import edu.northwestern.ono.position.OnoPeerManager;
import edu.northwestern.ono.position.OnoPeerManager.OnoPeer;
import edu.northwestern.ono.ui.OnoView;

/**
 * @author David Choffnes &lt;drchoffnes@cs.northwestern.edu&gt;
 *
 * The CustomerItem class ...
 */
public class CosineSimilarityItem extends CoreTableColumn implements
TableCellRefreshListener {


	/** Default Constructor */
	public CosineSimilarityItem() {
		super("cossim", POSITION_LAST, 100, OnoView.NEARBY_PEERS);
		this.setRefreshInterval(INTERVAL_LIVE);
	}



	public void refresh(TableCell cell) {
		OnoPeer op = (OnoPeer)cell.getDataSource();
		if (OnoPeerManager.getInstance().getOnoPeer(op.getIp())==null){
			OnoPeerManager.getInstance().addPeer(op);
		}
		String sText = OnoPeerManager.getInstance().getOnoPeer(op.getIp()).printCosSim(true);
//		= op.printCosSim(true);

		if (cell.setText(sText) || !cell.isValid()) {

			if (sText.length()<=2) cell.setSortValue(-1.0);
			else cell.setSortValue(op.getMaxCosSim().getValue());

		}

	}


	public void addCellRefreshListener(TableCellRefreshListener listener) {
//		if (listener == this) return;
		super.addCellRefreshListener(listener);
	}



	public List getCellRefreshListeners() {
		List myList = super.getCellRefreshListeners();
		if (!myList.contains(this)) myList.add(this);
		return myList;
	}


	



}

==> ono_1.9.9.jar: edu/northwestern/ono/ui/items/CosineSimilarityItem.java <==
/**
 * Ono Project
 *
 * File:         CustomerItem.java
 * RCS:          $Id: CosineSimilarityItem.java,v 1.7 2008/10/23 21:51:30 drc915 Exp $
 * Description:  CustomerItem class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 24, 2007 at 3:34:16 PM
 * Language:     Java
 * Package:      edu.northwestern.ono.ui.items
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.ono.ui.items;

import java.util.List;

import org.gudy.azureus2.plugins.ui.tables.TableCell;
import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;

import edu.northwestern.ono.MainGeneric;
import edu.northwestern.ono.tables.utils.CoreTableColumn;

import edu.northwestern.ono.position.OnoPeerManager;
import edu.northwestern.ono.position.OnoPeerManager.OnoPeer;
import edu.northwestern.ono.ui.OnoView;

/**
 * @author David Choffnes &lt;drchoffnes@cs.northwestern.edu&gt;
 *
 * The CustomerItem class ...
 */
public class CosineSimilarityItem extends CoreTableColumn implements
TableCellRefreshListener {


	/** Default Constructor */
	public CosineSimilarityItem() {
		super("cossim", POSITION_LAST, 100, OnoView.NEARBY_PEERS);
		this.setRefreshInterval(INTERVAL_LIVE);
	}



	public void refresh(TableCell cell) {
		OnoPeer op = (OnoPeer)cell.getDataSource();
		if (OnoPeerManager.getInstance().getOnoPeer(op.getIp())==null){
			OnoPeerManager.getInstance().addPeer(op);
		}
		String sText = OnoPeerManager.getInstance().getOnoPeer(op.getIp()).printCosSim(true);
		if (sText.length()<=2 && op.isCIDRMatch()) sText = "IP Match";
		//		= op.printCosSim(true);

		if (cell.setText(sText) || !cell.isValid()) {

			if (sText.length()<=2) cell.setSortValue(-1.0);
			else cell.setSortValue(op.getMaxCosSim()==null?sText:op.getMaxCosSim().getValue());

		}

	}


	public void addCellRefreshListener(TableCellRefreshListener listener) {
//		if (listener == this) return;
		super.addCellRefreshListener(listener);
	}



	public List getCellRefreshListeners() {
		List myList = super.getCellRefreshListeners();
		if (!myList.contains(this)) myList.add(this);
		return myList;
	}


	



}
